cli.PreprocessConfig

cli.PreprocessConfig(
    script,
    simulation,
    data_file,
    variable,
    units,
    output,
    amend=False,
    crs=None,
    x_coord=None,
    y_coord=None,
    time_coord=None,
    verbose=False,
)

Arguments for ‘java -jar joshsim.jar preprocess’ command.

Converts geospatial data (NetCDF, GeoTIFF) into Josh’s .jshd format.

Attributes

Name Type Description
script Path Path to Josh simulation file (.josh).
simulation str Name of simulation for preprocessing.
data_file Path Path to input data file (NetCDF, GeoTIFF, etc.).
variable str Variable name or band number to extract.
units str Units of the data for simulation use.
output Path Path for output preprocessed file (.jshd).
amend bool Amend existing JSHD file rather than overwriting.
crs str | None Coordinate Reference System for reading input file.
x_coord str | None Name of X coordinate dimension.
y_coord str | None Name of Y coordinate dimension.
time_coord str | None Name of time dimension.
verbose bool Enable verbose output.