grid.TimeAxis

grid.TimeAxis(type, start, count, unit=None, increment=None, interval=None)

Declared temporal axis shared by a grid’s time-varying resources.

A count axis has numeric coordinates, while an ISO axis has ISO-8601 coordinates. The axis count is the authoritative number of preprocessing slices and simulation timesteps for a temporal GridSpec.

Attributes

Name Description
steps_high Inclusive upper bound for a simulation with count timesteps.