jobs.FileSweepParameter
jobs.FileSweepParameter(name, paths=list())A file parameter to sweep over in job expansion.
Sweeps over different file paths for a given file_mapping key. Labels are derived from filename stems (e.g., “rcp45.jshd” → “rcp45”).
Attributes
| Name | Type | Description |
|---|---|---|
| name | str | Key in file_mappings (e.g., “climate”). |
| paths | list[Path] | List of file paths to sweep over. |
Methods
| Name | Description |
|---|---|
| from_dict | Create from dict (YAML/JSON deserialization). |
| to_dict | Convert to dict for YAML/JSON serialization. |
from_dict
jobs.FileSweepParameter.from_dict(data)Create from dict (YAML/JSON deserialization).
to_dict
jobs.FileSweepParameter.to_dict()Convert to dict for YAML/JSON serialization.